@@ -1,4 +1,4 @@
-//@line 41 "/usr/obj/i386/mozilla-firefox-2.0.0.16p3/mozilla/browser/base/content/openLocation.js"
+//@line 41 "/usr/obj/i386/mozilla-firefox-3.0.6/mozilla/browser/base/content/openLocation.js"
 
 var browser;
 var dialog = {};
@@ -73,10 +73,7 @@ function open()
                                         url, postData.value, null, null, true);
         break;
       case "3":
-        if (browser.getBrowser && browser.getBrowser().localName == "tabbrowser")
-          browser.delayedOpenTab(url, null, null, postData.value, true);
-        else
-          browser.loadURI(url, null, postData.value, true); // Just do a normal load.
+        browser.delayedOpenTab(url, null, null, postData.value, true);
         break;
     }
   }
@@ -119,12 +116,3 @@ function onChooseFile()
   }
   doEnabling();
 }
-
-function useUBHistoryItem(aMenuItem)
-{
-  var urlbar = document.getElementById("dialog.input");
-  urlbar.value = aMenuItem.getAttribute("label");
-  urlbar.focus();
-  doEnabling();
-}
-
