@@ -1,4 +1,4 @@
-//@line 38 "/usr/obj/ports/mozilla-firefox-2.0.0.16p3/mozilla/browser/components/preferences/connection.js"
+//@line 38 "/usr/obj/i386/mozilla-firefox-3.0.6/mozilla/browser/components/preferences/connection.js"
 
 var gConnectionsDialog = {
   beforeAccept: function ()
@@ -34,6 +34,12 @@ var gConnectionsDialog = {
     
     return true;
   },
+
+  checkForSystemProxy: function ()
+  {
+    if ("@mozilla.org/system-proxy-settings;1" in Components.classes)
+      document.getElementById("systemPref").removeAttribute("hidden");
+  },
   
   proxyTypeChanged: function ()
   {
@@ -56,9 +62,30 @@ var gConnectionsDialog = {
     
     var autoconfigURLPref = document.getElementById("network.proxy.autoconfig_url");
     autoconfigURLPref.disabled = proxyTypePref.value != 2;
-    
-    var disableReloadPref = document.getElementById("pref.advanced.proxies.disable_button.reload");
-    disableReloadPref.disabled = proxyTypePref.value != 2;
+
+    this.updateReloadButton();
+  },
+
+  updateReloadButton: function ()
+  {
+    // Disable the "Reload PAC" button if the selected proxy type is not PAC or
+    // if the current value of the PAC textbox does not match the value stored
+    // in prefs.  Likewise, disable the reload button if PAC is not configured
+    // in prefs.
+
+    var typedURL = document.getElementById("networkProxyAutoconfigURL").value;
+    var proxyTypeCur = document.getElementById("network.proxy.type").value;
+
+    var prefs =
+        Components.classes["@mozilla.org/preferences-service;1"].
+        getService(Components.interfaces.nsIPrefBranch);
+    var pacURL = prefs.getCharPref("network.proxy.autoconfig_url");
+    var proxyType = prefs.getIntPref("network.proxy.type");
+
+    var disableReloadPref =
+        document.getElementById("pref.advanced.proxies.disable_button.reload");
+    disableReloadPref.disabled =
+        (proxyTypeCur != 2 || proxyType != 2 || typedURL != pacURL);
   },
   
   readProxyType: function ()
@@ -115,10 +142,8 @@ var gConnectionsDialog = {
 
   reloadPAC: function ()
   {
-    var autoURL = document.getElementById("networkProxyAutoconfigURL");
-    var pps = Components.classes["@mozilla.org/network/protocol-proxy-service;1"]
-                        .getService(Components.interfaces.nsPIProtocolProxyService);
-    pps.configureFromPAC(autoURL.value);
+    Components.classes["@mozilla.org/network/protocol-proxy-service;1"].
+        getService().reloadPAC();
   },
   
   doAutoconfigURLFixup: function ()
