@@ -1,4 +1,4 @@
-//@line 40 "/usr/obj/i386/mozilla-firefox-2.0.0.16p3/mozilla/browser/components/preferences/languages.js"
+//@line 40 "/usr/obj/ports/mozilla-firefox-3.0.6/mozilla/browser/components/preferences/languages.js"
 
 var gLanguagesDialog = {
 
@@ -124,7 +124,7 @@ var gLanguagesDialog = {
     var preference = document.getElementById("intl.accept_languages");
     if (preference.value == "") 
       return undefined;
-    var languages = preference.value.split(/\s*,\s*/);
+    var languages = preference.value.toLowerCase().split(/\s*,\s*/);
     for (var i = 0; i < languages.length; ++i) {
       var name = this._getLanguageName(languages[i]);
       if (!name)
@@ -166,7 +166,7 @@ var gLanguagesDialog = {
   {
     var selectedID = this._availableLanguages.selectedItem.id;
     var preference = document.getElementById("intl.accept_languages");
-    var arrayOfPrefs = preference.value.split(/\s*,\s*/);
+    var arrayOfPrefs = preference.value.toLowerCase().split(/\s*,\s*/);
     for (var i = 0; i < arrayOfPrefs.length; ++i ){
       if (arrayOfPrefs[i] == selectedID)
         return;
