@@ -1,4 +1,4 @@
-//@line 39 "/usr/obj/i386/mozilla-firefox-2.0.0.16p3/mozilla/browser/components/preferences/permissions.js"
+//@line 39 "/usr/obj/i386/mozilla-firefox-3.0.6/mozilla/browser/components/preferences/permissions.js"
 
 const nsIPermissionManager = Components.interfaces.nsIPermissionManager;
 const nsICookiePermission = Components.interfaces.nsICookiePermission;
@@ -89,9 +89,10 @@ var gPermissionManager = {
     var exists = false;
     for (var i = 0; i < this._permissions.length; ++i) {
       if (this._permissions[i].rawHost == host) {
-        exists = true;
-        this._permissions[i].capability = capabilityString;
-        this._permissions[i].perm = aCapability;
+        // Avoid calling the permission manager if the capability settings are
+        // the same. Otherwise allow the call to the permissions manager to
+        // update the listbox for us.
+        exists = this._permissions[i].perm == aCapability;
         break;
       }
     }
@@ -120,8 +121,8 @@ var gPermissionManager = {
   
   onHostKeyPress: function (aEvent)
   {
-    if (aEvent.keyCode == 13)
-      gPermissionManager.addPermission(nsIPermissionManager.ALLOW_ACTION);
+    if (aEvent.keyCode == KeyEvent.DOM_VK_RETURN)
+      document.getElementById("btnAllow").click();
   },
   
   onLoad: function ()
@@ -133,7 +134,13 @@ var gPermissionManager = {
   
   init: function (aParams)
   {
+    if (this._type) {
+      // reusing an open dialog, clear the old observer
+      this.uninit();
+    }
+
     this._type = aParams.permissionType;
+    this._manageCapability = aParams.manageCapability;
     
     var permissionsText = document.getElementById("permissionsText");
     while (permissionsText.hasChildNodes())
@@ -145,12 +152,18 @@ var gPermissionManager = {
     document.getElementById("btnBlock").hidden    = !aParams.blockVisible;
     document.getElementById("btnSession").hidden  = !aParams.sessionVisible;
     document.getElementById("btnAllow").hidden    = !aParams.allowVisible;
-    
+
+    var urlFieldVisible = (aParams.blockVisible || aParams.sessionVisible || aParams.allowVisible);
+
     var urlField = document.getElementById("url");
     urlField.value = aParams.prefilledHost;
-    
+    urlField.hidden = !urlFieldVisible;
+
     this.onHostInput(urlField);
-    
+
+    var urlLabel = document.getElementById("urlLabel");
+    urlLabel.hidden = !urlFieldVisible;
+
     var os = Components.classes["@mozilla.org/observer-service;1"]
                        .getService(Components.interfaces.nsIObserverService);
     os.addObserver(this, "perm-changed", false);
@@ -291,7 +304,10 @@ var gPermissionManager = {
   
   _addPermissionToList: function (aPermission)
   {
-    if (aPermission.type == this._type) {
+    if (aPermission.type == this._type &&
+        (!this._manageCapability ||
+         (aPermission.capability == this._manageCapability))) {
+
       var host = aPermission.host;
       var capabilityString = this._getCapabilityString(aPermission.capability);
       var p = new Permission(host,
