@@ -1,4 +1,4 @@
-//@line 38 "/usr/obj/ports/mozilla-firefox-2.0.0.16p3/mozilla/browser/components/preferences/phishEULA.js"
+//@line 38 "/usr/obj/i386/mozilla-firefox-3.0.6/mozilla/browser/components/preferences/phishEULA.js"
 
 /**
  * gPhishDialog controls the user interface for displaying the privacy policy of
@@ -56,9 +56,15 @@ var gPhishDialog = {
 
     // add progress listener to enable OK, radios when page loads
     var frame = document.getElementById("phishPolicyFrame");
-    var webProgress = frame.docShell
-                           .QueryInterface(Ci.nsIInterfaceRequestor)
-                           .getInterface(Ci.nsIWebProgress);
+    var docShell = frame.docShell;
+
+    // disable unnecessary features
+    docShell.allowAuth = false;
+    docShell.allowPlugins = false;
+    docShell.allowSubframes = false;
+
+    var webProgress = docShell.QueryInterface(Ci.nsIInterfaceRequestor)
+                              .getInterface(Ci.nsIWebProgress);
     webProgress.addProgressListener(this._progressListener,
                                     Ci.nsIWebProgress.NOTIFY_STATE_WINDOW);
 
