@@ -1,5 +1,5 @@
 /*
-//@line 40 "/usr/obj/i386/mozilla-firefox-2.0.0.16p3/mozilla/browser/components/preferences/privacy.js"
+//@line 40 "/usr/obj/ports/mozilla-firefox-3.0.6/mozilla/browser/components/preferences/privacy.js"
 */
 
 var gPrivacyPane = {
@@ -10,7 +10,7 @@ var gPrivacyPane = {
    */
   init: function ()
   {
-    this.updateHistoryDaysUI();
+    this._updateHistoryDaysUI();
     this.updateClearNowButtonLabel();
   },
 
@@ -19,11 +19,20 @@ var gPrivacyPane = {
   /*
    * Preferences:
    *
+   * NOTE: These first two are no longer shown in the UI. They're controlled
+   *       via the checkbox, which uses the zero state of the pref to turn
+   *       history off.
    * browser.history_expire_days
    * - the number of days of history to remember
    * browser.history_expire_days.mirror
    * - a preference whose value mirrors that of browser.history_expire_days, to
    *   make the "days of history" checkbox easier to code
+   *
+   * browser.history_expire_days_min
+   * - the mininum number of days of history to remember
+   * browser.history_expire_days_min.mirror
+   * - a preference whose value mirrors that of browser.history_expire_days_min
+   *   to make the "days of history" checkbox easier to code
    * browser.formfill.enable
    * - true if entries in forms and the search bar should be saved, false
    *   otherwise
@@ -41,38 +50,21 @@ var gPrivacyPane = {
    * days-of-history checkbox so that updates to the textbox are transmitted to
    * the real days-of-history preference.
    */
-  updateHistoryDaysUI: function ()
+  _updateHistoryDaysUI: function ()
   {
     var pref = document.getElementById("browser.history_expire_days");
     var mirror = document.getElementById("browser.history_expire_days.mirror");
+    var pref_min = document.getElementById("browser.history_expire_days_min");
     var textbox = document.getElementById("historyDays");
     var checkbox = document.getElementById("rememberHistoryDays");
 
     // handle mirror non-existence or mirror/pref unsync
-    if (mirror.value === null || mirror.value != pref.value)
+    if (mirror.value === null || mirror.value != pref.value || 
+        (mirror.value == pref.value && mirror.value == 0) )
       mirror.value = pref.value ? pref.value : pref.defaultValue;
 
     checkbox.checked = (pref.value > 0);
-    textbox.disabled = !(pref.value > 0);
-
-    // hook up textbox to mirror preference and force a preference read
-    textbox.setAttribute("onsynctopreference", "return gPrivacyPane._writeHistoryDaysMirror();");
-    textbox.setAttribute("preference", "browser.history_expire_days.mirror");
-    mirror.updateElements();
-  },
-
-  /**
-   * Stores the days of history to the actual days-of-history preference and
-   * returns that value, to be stored in the mirror preference.
-   */
-  _writeHistoryDaysMirror: function ()
-  {
-    var pref = document.getElementById("browser.history_expire_days");
-    var textbox = document.getElementById("historyDays");
-    pref.value = textbox.value;
-
-    // don't override the value in the textbox
-    return undefined;
+    textbox.disabled = !checkbox.checked;
   },
 
   /**
@@ -91,6 +83,19 @@ var gPrivacyPane = {
     textbox.disabled = !checkbox.checked;
   },
 
+  /**
+   * Responds to changes in the days-of-history textbox,
+   * unchecking the history-enabled checkbox if the days
+   * value is zero.
+   */
+  onkeyupHistoryDaysText: function ()
+  {
+    var textbox = document.getElementById("historyDays");
+    var checkbox = document.getElementById("rememberHistoryDays");
+    
+    checkbox.checked = textbox.value != 0;
+  },
+
   /**
    * Converts the value of the browser.download.manager.retention preference
    * into a Boolean value.  "remove on close" and "don't remember" both map
@@ -120,10 +125,9 @@ var gPrivacyPane = {
    * network.cookie.cookieBehavior
    * - determines how the browser should handle cookies:
    *     0   means enable all cookies
-   *     1   means allow cookies from the "originating" server only; see
+   *     1   means reject third party cookies; see
    *         netwerk/cookie/src/nsCookieService.cpp for a hairier definition
    *     2   means disable all cookies
-   *     3   means use P3P policy to decide, which is probably broken
    * network.cookie.lifetimePolicy
    * - determines how long cookies are stored:
    *     0   means keep cookies until they expire
@@ -133,31 +137,51 @@ var gPrivacyPane = {
 
   /**
    * Reads the network.cookie.cookieBehavior preference value and
-   * enables/disables the "Keep until:" UI accordingly, returning true
+   * enables/disables the rest of the cookie UI accordingly, returning true
    * if cookies are enabled.
    */
   readAcceptCookies: function ()
   {
     var pref = document.getElementById("network.cookie.cookieBehavior");
+    var acceptThirdParty = document.getElementById("acceptThirdParty");
     var keepUntil = document.getElementById("keepUntil");
     var menu = document.getElementById("keepCookiesUntil");
 
-    // anything other than "disable all cookies" maps to "accept cookies"
+    // enable the rest of the UI for anything other than "disable all cookies"
     var acceptCookies = (pref.value != 2);
 
-    keepUntil.disabled = menu.disabled = !acceptCookies;
+    keepUntil.disabled = menu.disabled = acceptThirdParty.disabled = !acceptCookies;
     
     return acceptCookies;
   },
 
+  readAcceptThirdPartyCookies: function ()
+  {
+    var pref = document.getElementById("network.cookie.cookieBehavior");
+    return pref.value == 0;
+  },
+
   /**
    * Enables/disables the "keep until" label and menulist in response to the
    * "accept cookies" checkbox being checked or unchecked.
    */
   writeAcceptCookies: function ()
   {
-    var checkbox = document.getElementById("acceptCookies");
-    return checkbox.checked ? 0 : 2;
+    var accept = document.getElementById("acceptCookies");
+    var acceptThirdParty = document.getElementById("acceptThirdParty");
+
+    // if we're enabling cookies, automatically check 'accept third party'
+    if (accept.checked)
+      acceptThirdParty.checked = true;
+
+    return accept.checked ? (acceptThirdParty.checked ? 0 : 1) : 2;
+  },
+
+  writeAcceptThirdPartyCookies: function ()
+  {
+    var accept = document.getElementById("acceptCookies");
+    var acceptThirdParty = document.getElementById("acceptThirdParty");
+    return accept.checked ? (acceptThirdParty.checked ? 0 : 1) : 2;
   },
 
   /**
