@@ -1,4 +1,4 @@
-//@line 39 "/usr/obj/i386/mozilla-firefox-2.0.0.16p3/mozilla/browser/base/content/safeMode.js"
+//@line 39 "/usr/obj/i386/mozilla-firefox-3.0.6/mozilla/browser/base/content/safeMode.js"
 
 function restartApp() {
   var appStartup = Components.classes["@mozilla.org/toolkit/app-startup;1"]
@@ -45,8 +45,7 @@ function disableAddons() {
   const nsIUpdateItem = Components.interfaces.nsIUpdateItem;
   var em = Components.classes["@mozilla.org/extensions/manager;1"]
                      .getService(Components.interfaces.nsIExtensionManager);
-  var type = nsIUpdateItem.TYPE_EXTENSION + nsIUpdateItem.TYPE_LOCALE +
-             nsIUpdateItem.TYPE_PLUGIN;
+  var type = nsIUpdateItem.TYPE_EXTENSION + nsIUpdateItem.TYPE_LOCALE;
   var items = em.getItemList(type, { });
   for (var i = 0; i < items.length; ++i)
     em.disableItem(items[i].id);
