@@ -1,4 +1,4 @@
-//@line 39 "/usr/obj/ports/mozilla-firefox-2.0.0.16p3/mozilla/browser/base/content/sanitize.js"
+//@line 39 "/usr/obj/ports/mozilla-firefox-3.0.6/mozilla/browser/base/content/sanitize.js"
 
 function Sanitizer() {}
 Sanitizer.prototype = {
@@ -86,6 +86,28 @@ Sanitizer.prototype = {
       }
     },
     
+    offlineApps: {
+      clear: function ()
+      {
+        const Cc = Components.classes;
+        const Ci = Components.interfaces;
+        var cacheService = Cc["@mozilla.org/network/cache-service;1"].
+                           getService(Ci.nsICacheService);
+        try {
+          cacheService.evictEntries(Ci.nsICache.STORE_OFFLINE);
+        } catch(er) {}
+
+        var storageManagerService = Cc["@mozilla.org/dom/storagemanager;1"].
+                                    getService(Ci.nsIDOMStorageManager);
+        storageManagerService.clearOfflineApps();
+      },
+
+      get canClear()
+      {
+          return true;
+      }
+    },
+
     history: {
       clear: function ()
       {
@@ -99,6 +121,14 @@ Sanitizer.prototype = {
           os.notifyObservers(null, "browser:purge-session-history", "");
         }
         catch (e) { }
+        
+        // Clear last URL of the Open Web Location dialog
+        var prefs = Components.classes["@mozilla.org/preferences-service;1"]
+                              .getService(Components.interfaces.nsIPrefBranch2);
+        try {
+          prefs.clearUserPref("general.open_location.last_url");
+        }
+        catch (e) { }
       },
       
       get canClear()
@@ -120,8 +150,7 @@ Sanitizer.prototype = {
           var searchBar = windows.getNext().document.getElementById("searchbar");
           if (searchBar) {
             searchBar.value = "";
-            searchBar.textbox.editor.enableUndo(false);
-            searchBar.textbox.editor.enableUndo(true);
+            searchBar.textbox.editor.transactionManager.clear();
           }
         }
 
@@ -157,24 +186,17 @@ Sanitizer.prototype = {
     passwords: {
       clear: function ()
       {
-        var pwmgr = Components.classes["@mozilla.org/passwordmanager;1"]
-                              .getService(Components.interfaces.nsIPasswordManager);
-        var e = pwmgr.enumerator;
-        var passwds = [];
-        while (e.hasMoreElements()) {
-          var passwd = e.getNext().QueryInterface(Components.interfaces.nsIPassword);
-          passwds.push(passwd);
-        }
-        
-        for (var i = 0; i < passwds.length; ++i)
-          pwmgr.removeUser(passwds[i].host, passwds[i].user);
+        var pwmgr = Components.classes["@mozilla.org/login-manager;1"]
+                              .getService(Components.interfaces.nsILoginManager);
+        pwmgr.removeAllLogins();
       },
       
       get canClear()
       {
-        var pwmgr = Components.classes["@mozilla.org/passwordmanager;1"]
-                              .getService(Components.interfaces.nsIPasswordManager);
-        return pwmgr.enumerator.hasMoreElements();
+        var pwmgr = Components.classes["@mozilla.org/login-manager;1"]
+                              .getService(Components.interfaces.nsILoginManager);
+        var count = pwmgr.countLogins("", "", ""); // count all logins
+        return (count > 0);
       }
     },
     
@@ -222,9 +244,9 @@ Sanitizer.showUI = function(aParentWindow)
 {
   var ww = Components.classes["@mozilla.org/embedcomp/window-watcher;1"]
                      .getService(Components.interfaces.nsIWindowWatcher);
-//@line 265 "/usr/obj/ports/mozilla-firefox-2.0.0.16p3/mozilla/browser/base/content/sanitize.js"
+//@line 287 "/usr/obj/ports/mozilla-firefox-3.0.6/mozilla/browser/base/content/sanitize.js"
   ww.openWindow(aParentWindow,
-//@line 267 "/usr/obj/ports/mozilla-firefox-2.0.0.16p3/mozilla/browser/base/content/sanitize.js"
+//@line 289 "/usr/obj/ports/mozilla-firefox-3.0.6/mozilla/browser/base/content/sanitize.js"
                 "chrome://browser/content/sanitize.xul",
                 "Sanitize",
                 "chrome,titlebar,centerscreen,modal",
