@@ -1,4 +1,4 @@
-//@line 39 "/usr/obj/ports/mozilla-firefox-2.0.0.16p3/mozilla/browser/components/search/content/engineManager.js"
+//@line 40 "/usr/obj/i386/mozilla-firefox-3.0.6/mozilla/browser/components/search/content/engineManager.js"
 
 const Ci = Components.interfaces;
 const Cc = Components.classes;
@@ -109,15 +109,78 @@ var gEngineManagerDialog = {
     gEngineView.invalidate();
     gEngineView.selection.select(newIndex);
     gEngineView.ensureRowIsVisible(newIndex);
+    this.showRestoreDefaults(true);
     document.getElementById("engineList").focus();
   },
 
+  editKeyword: function engineManager_editKeyword() {
+    var selectedEngine = gEngineView.selectedEngine;
+    if (!selectedEngine)
+      return;
+
+    var prompt = Cc["@mozilla.org/embedcomp/prompt-service;1"].
+                 getService(Ci.nsIPromptService);
+    var alias = { value: selectedEngine.alias };
+    var strings = document.getElementById("engineManagerBundle");
+    var title = strings.getString("editTitle");
+    var msg = strings.getFormattedString("editMsg", [selectedEngine.name]);
+
+    while (prompt.prompt(window, title, msg, alias, null, { })) {
+      var bduplicate = false;
+      var eduplicate = false;
+
+      if (alias.value != "") {
+        var searchService = Cc["@mozilla.org/browser/search-service;1"].
+                            getService(Ci.nsIBrowserSearchService);
+        var engine = searchService.getEngineByAlias(alias.value);
+
+        if (engine) {
+          if (engine.name != selectedEngine.name)
+            eduplicate = true;
+        } else {
+          try {
+            var bmserv = Cc["@mozilla.org/browser/nav-bookmarks-service;1"].
+                         getService(Ci.nsINavBookmarksService);
+            if (bmserv.getURIForKeyword(alias.value))
+              bduplicate = true;
+          } catch(ex) {}
+
+          // Check for duplicates in changes we haven't committed yet
+          var engines = gEngineView._engineStore.engines;
+          for each (var engine in engines) {
+            if (engine.alias == alias.value && 
+                engine.name != selectedEngine.name) {
+              eduplicate = true;
+              break;
+            }
+          }
+        }
+      }
+
+      // Notify the user if they have chosen an existing engine/bookmark keyword
+      if (eduplicate || bduplicate) {
+        var dtitle = strings.getString("duplicateTitle");
+        var bmsg = strings.getString("duplicateBookmarkMsg");
+        var emsg = strings.getFormattedString("duplicateEngineMsg",
+                                              [engine.name]);
+
+        prompt.alert(window, dtitle, (eduplicate) ? emsg : bmsg);
+      } else {
+        gEngineView._engineStore.changeEngine(selectedEngine, "alias",
+                                              alias.value);
+        gEngineView.invalidate();
+        break;
+      }
+    }
+  },
+
   onSelect: function engineManager_onSelect() {
     // buttons only work if an engine is selected and it's not the last engine
     var disableButtons = (gEngineView.selectedIndex == -1) ||
                          (gEngineView.lastIndex == 0);
     var lastSelected = (gEngineView.selectedIndex == gEngineView.lastIndex);
     var firstSelected = (gEngineView.selectedIndex == 0);
+    var noSelection = (gEngineView.selectedIndex == -1);
 
     document.getElementById("cmd_remove").setAttribute("disabled",
                                                        disableButtons);
@@ -127,6 +190,8 @@ var gEngineManagerDialog = {
 
     document.getElementById("cmd_movedown").setAttribute("disabled",
                                              disableButtons || lastSelected);
+    document.getElementById("cmd_editkeyword").setAttribute("disabled",
+                                                            noSelection);
   }
 };
 
@@ -195,6 +260,23 @@ EngineUnhideOp.prototype = {
   }
 }
 
+function EngineChangeOp(aEngineClone, aProp, aValue) {
+  if (!aEngineClone)
+    throw new Error("bad args to new EngineChangeOp!");
+
+  this._engine = aEngineClone.originalEngine;
+  this._prop = aProp;
+  this._newValue = aValue;
+}
+EngineChangeOp.prototype = {
+  _engine: null,
+  _prop: null,
+  _newValue: null,
+  commit: function ECO_commit() {
+    this._engine[this._prop] = this._newValue;
+  }
+}
+
 function EngineStore() {
   var searchService = Cc["@mozilla.org/browser/search-service;1"].
                       getService(Ci.nsIBrowserSearchService);
@@ -228,6 +310,8 @@ EngineStore.prototype = {
     for each (var engine in this._engines)
       if (engine.name == aName)
         return engine;
+
+    return null;
   },
 
   _cloneEngine: function ES_cloneObj(aEngine) {
@@ -309,6 +393,15 @@ EngineStore.prototype = {
     return added;
   },
 
+  changeEngine: function ES_changeEngine(aEngine, aProp, aNewValue) {
+    var index = this._getIndexForEngine(aEngine);
+    if (index == -1)
+      throw new Error("invalid engine?");
+
+    this._engines[index][aProp] = aNewValue;
+    this._ops.push(new EngineChangeOp(aEngine, aProp, aNewValue));
+  },
+
   reloadIcons: function ES_reloadIcons() {
     this._engines.forEach(function (e) {
       e.uri = e.originalEngine.uri;
@@ -391,6 +484,8 @@ EngineView.prototype = {
   getCellText: function(index, column) {
     if (column.id == "engineName")
       return this._engineStore.engines[index].name;
+    else if (column.id == "engineKeyword")
+      return this._engineStore.engines[index].alias;
     return "";
   },
 
@@ -418,6 +513,7 @@ EngineView.prototype = {
     }
 
     this._engineStore.moveEngine(sourceEngine, dropIndex);
+    gEngineManagerDialog.showRestoreDefaults(true);
 
     // Redraw, and adjust selection
     this.invalidate();
@@ -444,6 +540,7 @@ EngineView.prototype = {
   selectionChanged: function() { },
   cycleCell: function(row, column) { },
   isEditable: function(index, column) { return false; },
+  isSelectable: function(index, column) { return false; },
   setCellValue: function(index, column, value) { },
   setCellText: function(index, column, value) { },
   performAction: function(action) { },
