@@ -1,39 +1,4 @@
-/* ***** BEGIN LICENSE BLOCK *****
- * Version: MPL 1.1/GPL 2.0/LGPL 2.1
- *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * The Original Code is the Mozilla Firefox browser.
- *
- * The Initial Developer of the Original Code is
- * Benjamin Smedberg <benjamin@smedbergs.us>
- *
- * Portions created by the Initial Developer are Copyright (C) 2004
- * the Initial Developer. All Rights Reserved.
- *
- * Contributor(s):
- *
- * Alternatively, the contents of this file may be used under the terms of
- * either the GNU General Public License Version 2 or later (the "GPL"), or
- * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
- * in which case the provisions of the GPL or the LGPL are applicable instead
- * of those above. If you wish to allow use of your version of this file only
- * under the terms of either the GPL or the LGPL, and not to allow others to
- * use your version of this file under the terms of the MPL, indicate your
- * decision by deleting the provisions above and replace them with the notice
- * and other provisions required by the GPL or the LGPL. If you do not delete
- * the provisions above, a recipient may use your version of this file under
- * the terms of any one of the MPL, the GPL or the LGPL.
- *
- * ***** END LICENSE BLOCK ***** */
+//@line 37 "/usr/obj/ports/mozilla-firefox-3.0.6/mozilla/browser/components/nsBrowserContentHandler.js"
 
 const nsISupports            = Components.interfaces.nsISupports;
 
@@ -49,9 +14,9 @@ const nsIDOMChromeWindow     = Components.interfaces.nsIDOMChromeWindow;
 const nsIDOMWindow           = Components.interfaces.nsIDOMWindow;
 const nsIFactory             = Components.interfaces.nsIFactory;
 const nsIFileURL             = Components.interfaces.nsIFileURL;
-const nsIJARURI              = Components.interfaces.nsIJARURI;
 const nsIHttpProtocolHandler = Components.interfaces.nsIHttpProtocolHandler;
 const nsIInterfaceRequestor  = Components.interfaces.nsIInterfaceRequestor;
+const nsINetUtil             = Components.interfaces.nsINetUtil;
 const nsIPrefBranch          = Components.interfaces.nsIPrefBranch;
 const nsIPrefLocalizedString = Components.interfaces.nsIPrefLocalizedString;
 const nsISupportsString      = Components.interfaces.nsISupportsString;
@@ -68,6 +33,9 @@ const NS_BINDING_ABORTED = 0x804b0002;
 const NS_ERROR_WONT_HANDLE_CONTENT = 0x805d0001;
 const NS_ERROR_ABORT = Components.results.NS_ERROR_ABORT;
 
+const URI_INHERITS_SECURITY_CONTEXT = nsIHttpProtocolHandler
+                                        .URI_INHERITS_SECURITY_CONTEXT;
+
 function shouldLoadURI(aURI) {
   if (aURI && !aURI.schemeIs("chrome"))
     return true;
@@ -132,6 +100,13 @@ function needHomepageOverride(prefb) {
                          .getService(nsIHttpProtocolHandler).misc;
 
   if (mstone != savedmstone) {
+    // Bug 462254. Previous releases had a default pref to suppress the EULA
+    // agreement if the platform's installer had already shown one. Now with
+    // about:rights we've removed the EULA stuff and default pref, but we need
+    // a way to make existing profiles retain the default that we removed.
+    if (savedmstone)
+      prefb.setBoolPref("browser.rights.3.shown", true);
+    
     prefb.setCharPref("browser.startup.homepage_override.mstone", mstone);
     return (savedmstone ? OVERRIDE_NEW_MSTONE : OVERRIDE_NEW_PROFILE);
   }
@@ -247,27 +222,27 @@ function getMostRecentWindow(aType) {
   return wm.getMostRecentWindow(aType);
 }
 
-//@line 258 "/usr/obj/i386/mozilla-firefox-2.0.0.16p3/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 268 "/usr/obj/ports/mozilla-firefox-3.0.6/mozilla/browser/components/nsBrowserContentHandler.js"
 
 // this returns the most recent non-popup browser window
 function getMostRecentBrowserWindow() {
   var wm = Components.classes["@mozilla.org/appshell/window-mediator;1"]
                      .getService(Components.interfaces.nsIWindowMediator);
 
-//@line 265 "/usr/obj/i386/mozilla-firefox-2.0.0.16p3/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 275 "/usr/obj/ports/mozilla-firefox-3.0.6/mozilla/browser/components/nsBrowserContentHandler.js"
   var win = wm.getMostRecentWindow("navigator:browser", true);
 
   // if we're lucky, this isn't a popup, and we can just return this
-  if (win && !win.toolbar.visible) {
+  if (win && win.document.documentElement.getAttribute("chromehidden")) {
     var windowList = wm.getEnumerator("navigator:browser", true);
     // this is oldest to newest, so this gets a bit ugly
     while (windowList.hasMoreElements()) {
       var nextWin = windowList.getNext();
-      if (nextWin.toolbar.visible)
+      if (!nextWin.document.documentElement.getAttribute("chromehidden"))
         win = nextWin;
     }
   }
-//@line 290 "/usr/obj/i386/mozilla-firefox-2.0.0.16p3/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 300 "/usr/obj/ports/mozilla-firefox-3.0.6/mozilla/browser/components/nsBrowserContentHandler.js"
 
   return win;
 }
@@ -329,7 +304,7 @@ var nsBrowserContentHandler = {
         !iid.equals(nsIContentHandler) &&
         !iid.equals(nsICommandLineValidator) &&
         !iid.equals(nsIFactory))
-      throw Components.errors.NS_ERROR_NO_INTERFACE;
+      throw Components.results.NS_ERROR_NO_INTERFACE;
 
     return this;
   },
@@ -459,19 +434,12 @@ var nsBrowserContentHandler = {
         openPreferences();
         cmdLine.preventDefault = true;
       } else try {
-        // only load URIs which do not inherit chrome privs.
-
-        // normally would call checkLoadURI(..., DISALLOW_SCRIPT_OR_DATA)
-        // for this, but in this context we crash when the security manager
-        // tries to throw an exception (no window object here). On the branch
-        // we need to simulate the important bits
+        // only load URIs which do not inherit chrome privs
+        var features = "chrome,dialog=no,all" + this.getFeatures(cmdLine);
         var uri = resolveURIInternal(cmdLine, chromeParam);
-        while (uri instanceof nsIJARURI) {
-          // unpack to find the real scheme
-          uri = uri.JARFile;
-        }
-        if (!uri.schemeIs("javascript") && !uri.schemeIs("data")) {
-          var features = "chrome,dialog=no,all" + this.getFeatures(cmdLine);
+        var netutil = Components.classes["@mozilla.org/network/util;1"]
+                                .getService(nsINetUtil);
+        if (!netutil.URIChainHasFlags(uri, URI_INHERITS_SECURITY_CONTEXT)) {
           openWindow(null, uri.spec, "_blank", features);
           cmdLine.preventDefault = true;
         }
@@ -493,7 +461,7 @@ var nsBrowserContentHandler = {
       cmdLine.preventDefault = true;
     }
 
-//@line 528 "/usr/obj/i386/mozilla-firefox-2.0.0.16p3/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 531 "/usr/obj/ports/mozilla-firefox-3.0.6/mozilla/browser/components/nsBrowserContentHandler.js"
   },
 
   helpInfo : "  -browser            Open a browser window.\n",
@@ -511,11 +479,11 @@ var nsBrowserContentHandler = {
     try {
       switch (needHomepageOverride(prefb)) {
         case OVERRIDE_NEW_PROFILE:
-          // New profile.
+          // New profile
           overridePage = formatter.formatURLPref("startup.homepage_welcome_url");
           break;
         case OVERRIDE_NEW_MSTONE:
-          // Existing profile.
+          // Existing profile, new build
           copyPrefOverride();
 
           // Check whether we have a session to restore. If we do, we assume
@@ -525,8 +493,8 @@ var nsBrowserContentHandler = {
           haveUpdateSession = ss.doRestore();
           overridePage = formatter.formatURLPref("startup.homepage_override_url");
           break;
-      }
-    } catch (e) {}
+    }
+    } catch (ex) {}
 
     // formatURLPref might return "about:blank" if getting the pref fails
     if (overridePage == "about:blank")
@@ -535,7 +503,7 @@ var nsBrowserContentHandler = {
     var startPage = "";
     try {
       var choice = prefb.getIntPref("browser.startup.page");
-      if (choice == 1)
+      if (choice == 1 || choice == 3)
         startPage = this.startPage;
 
       if (choice == 2)
@@ -551,7 +519,7 @@ var nsBrowserContentHandler = {
     // Only show the startPage if we're not restoring an update session.
     if (overridePage && startPage && !haveUpdateSession)
       return overridePage + "|" + startPage;
- 
+
     return overridePage || startPage || "about:blank";
   },
 
@@ -624,16 +592,9 @@ var nsBrowserContentHandler = {
       throw NS_ERROR_WONT_HANDLE_CONTENT;
     }
 
-    var parentWin;
-    try {
-      parentWin = context.getInterface(nsIDOMWindow);
-    }
-    catch (e) {
-    }
-
     request.QueryInterface(nsIChannel);
-    
-    openWindow(parentWin, request.URI, "_blank", null, null);
+    handURIToExistingBrowser(request.URI,
+      nsIBrowserDOMWindow.OPEN_DEFAULTWINDOW, null);
     request.cancel(NS_BINDING_ABORTED);
   },
 
@@ -700,7 +661,7 @@ var nsDefaultCommandLineHandler = {
     if (!iid.equals(nsISupports) &&
         !iid.equals(nsICommandLineHandler) &&
         !iid.equals(nsIFactory))
-      throw Components.errors.NS_ERROR_NO_INTERFACE;
+      throw Components.results.NS_ERROR_NO_INTERFACE;
 
     return this;
   },
@@ -709,13 +670,13 @@ var nsDefaultCommandLineHandler = {
   // running and have already been handled. This is compared against uri's
   // opened using DDE on Win32 so we only open one of the requests.
   _handledURIs: [ ],
-//@line 746 "/usr/obj/i386/mozilla-firefox-2.0.0.16p3/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 742 "/usr/obj/ports/mozilla-firefox-3.0.6/mozilla/browser/components/nsBrowserContentHandler.js"
 
   /* nsICommandLineHandler */
   handle : function dch_handle(cmdLine) {
     var urilist = [];
 
-//@line 772 "/usr/obj/i386/mozilla-firefox-2.0.0.16p3/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 768 "/usr/obj/ports/mozilla-firefox-3.0.6/mozilla/browser/components/nsBrowserContentHandler.js"
 
     try {
       var ar;
@@ -777,7 +738,7 @@ var nsDefaultCommandLineHandler = {
         }
       }
 
-      var URLlist = urilist.filter(shouldLoadURI).map(function (u) { return u.spec; });
+      var URLlist = urilist.filter(shouldLoadURI).map(function (u) u.spec);
       if (URLlist.length) {
         openWindow(null, nsBrowserContentHandler.chromeURL, "_blank",
                    "chrome,dialog=no,all" + nsBrowserContentHandler.getFeatures(cmdLine),
@@ -834,6 +795,15 @@ var Module = {
   },
     
   registerSelf: function mod_regself(compMgr, fileSpec, location, type) {
+    if (Components.classes["@mozilla.org/xre/app-info;1"]) {
+      // Don't register these if Firefox is launching a XULRunner application
+      const FIREFOX_UID = "{ec8030f7-c20a-464f-9b0e-13a3a9e97384}";
+      var appInfo = Components.classes["@mozilla.org/xre/app-info;1"]
+                              .getService(Components.interfaces.nsIXULAppInfo);
+      if (appInfo.ID != FIREFOX_UID)
+        return;
+    }
+
     var compReg =
       compMgr.QueryInterface( Components.interfaces.nsIComponentRegistrar );
 
@@ -861,9 +831,9 @@ var Module = {
 
     registerType("text/html");
     registerType("application/vnd.mozilla.xul+xml");
-//@line 918 "/usr/obj/i386/mozilla-firefox-2.0.0.16p3/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 923 "/usr/obj/ports/mozilla-firefox-3.0.6/mozilla/browser/components/nsBrowserContentHandler.js"
     registerType("image/svg+xml");
-//@line 920 "/usr/obj/i386/mozilla-firefox-2.0.0.16p3/mozilla/browser/components/nsBrowserContentHandler.js"
+//@line 925 "/usr/obj/ports/mozilla-firefox-3.0.6/mozilla/browser/components/nsBrowserContentHandler.js"
     registerType("text/rdf");
     registerType("text/xml");
     registerType("application/xhtml+xml");
