@@ -1,45 +1,4 @@
-/* -*- Mode: C++; tab-width: 4; indent-tabs-mode: nil; c-basic-offset: 4 -*-
- * ***** BEGIN LICENSE BLOCK *****
- * Version: MPL 1.1/GPL 2.0/LGPL 2.1
- *
- * The contents of this file are subject to the Mozilla Public License Version
- * 1.1 (the "License"); you may not use this file except in compliance with
- * the License. You may obtain a copy of the License at
- * http://www.mozilla.org/MPL/
- *
- * Software distributed under the License is distributed on an "AS IS" basis,
- * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
- * for the specific language governing rights and limitations under the
- * License.
- *
- * The Original Code is mozilla.org code.
- *
- * The Initial Developer of the Original Code is
- * Netscape Communications Corporation.
- * Portions created by the Initial Developer are Copyright (C) 1999
- * the Initial Developer. All Rights Reserved.
- *
- * Contributor(s):
- *   Stephen Lamm            <slamm@netscape.com>
- *   Robert John Churchill   <rjc@netscape.com>
- *   David Hyatt             <hyatt@mozilla.org>
- *   Christopher A. Aillon   <christopher@aillon.com>
- *   Myk Melez               <myk@mozilla.org>
- *   Pamela Greene           <pamg.bugs@gmail.com>
- *
- * Alternatively, the contents of this file may be used under the terms of
- * either the GNU General Public License Version 2 or later (the "GPL"), or
- * the GNU Lesser General Public License Version 2.1 or later (the "LGPL"),
- * in which case the provisions of the GPL or the LGPL are applicable instead
- * of those above. If you wish to allow use of your version of this file only
- * under the terms of either the GPL or the LGPL, and not to allow others to
- * use your version of this file under the terms of the MPL, indicate your
- * decision by deleting the provisions above and replace them with the notice
- * and other provisions required by the GPL or the LGPL. If you do not delete
- * the provisions above, a recipient may use your version of this file under
- * the terms of any one of the MPL, the GPL or the LGPL.
- *
- * ***** END LICENSE BLOCK ***** */
+//@line 43 "/usr/obj/i386/mozilla-firefox-3.0.6/mozilla/browser/components/sidebar/src/nsSidebar.js"
 
 /*
  * No magic constructor behaviour, as is de rigeur for XPCOM.
@@ -57,16 +16,13 @@
 
 const DEBUG = false; /* set to false to suppress debug messages */
 
-const SIDEBAR_CONTRACTID            = "@mozilla.org/sidebar;1";
-const SIDEBAR_CID                   = Components.ID("{22117140-9c6e-11d3-aaf1-00805f8a4905}");
-const NETSEARCH_CONTRACTID          = "@mozilla.org/rdf/datasource;1?name=internetsearch"
-const nsISupports                   = Components.interfaces.nsISupports;
-const nsIFactory                    = Components.interfaces.nsIFactory;
-const nsISidebar                    = Components.interfaces.nsISidebar;
-const nsISidebar_MOZILLA_1_8_BRANCH = Components.interfaces.nsISidebar_MOZILLA_1_8_BRANCH;
-const nsISidebarExternal            = Components.interfaces.nsISidebarExternal;
-const nsIInternetSearchService      = Components.interfaces.nsIInternetSearchService;
-const nsIClassInfo                  = Components.interfaces.nsIClassInfo;
+const SIDEBAR_CONTRACTID        = "@mozilla.org/sidebar;1";
+const SIDEBAR_CID               = Components.ID("{22117140-9c6e-11d3-aaf1-00805f8a4905}");
+const nsISupports               = Components.interfaces.nsISupports;
+const nsIFactory                = Components.interfaces.nsIFactory;
+const nsISidebar                = Components.interfaces.nsISidebar;
+const nsISidebarExternal        = Components.interfaces.nsISidebarExternal;
+const nsIClassInfo              = Components.interfaces.nsIClassInfo;
 
 // File extension for Sherlock search plugin description files
 const SHERLOCK_FILE_EXT_REGEXP = /\.src$/i;
@@ -124,18 +80,15 @@ function (aTitle, aContentURL, aCustomizeURL, aPersist)
     if (!sidebarURLSecurityCheck(aContentURL))
       return;
 
-    var dialogArgs = {
-      name: aTitle,
-      url: aContentURL,
-      bWebPanel: true
+    var uri = null;
+    var ioService = Components.classes["@mozilla.org/network/io-service;1"]
+                              .getService(Components.interfaces.nsIIOService);
+    try {
+      uri = ioService.newURI(aContentURL, null, null);
     }
-    var features;
-    if (!/Mac/.test(win.navigator.platform))
-      features = "centerscreen,chrome,dialog,resizable,dependent";
-    else
-      features = "chrome,dialog,resizable,modal";
-    win.openDialog("chrome://browser/content/bookmarks/addBookmark2.xul", "",
-                   features, dialogArgs);
+    catch(ex) { return; }
+
+    win.PlacesUIUtils.showMinimalAddBookmarkUI(uri, aTitle, null, null, true, true);
 }
 
 nsSidebar.prototype.validateSearchEngine =
@@ -268,8 +221,7 @@ nsSidebar.prototype.classDescription = "Sidebar";
 
 // method of nsIClassInfo
 nsSidebar.prototype.getInterfaces = function(count) {
-    var interfaceList = [nsISidebar, nsISidebar_MOZILLA_1_8_BRANCH, 
-                         nsIClassInfo, nsISidebarExternal];
+    var interfaceList = [nsISidebar, nsISidebarExternal, nsIClassInfo];
     count.value = interfaceList.length;
     return interfaceList;
 }
@@ -279,11 +231,10 @@ nsSidebar.prototype.getHelperForLanguage = function(count) {return null;}
 
 nsSidebar.prototype.QueryInterface =
 function (iid) {
-    if (!iid.equals(nsISidebar) && 
+    if (!iid.equals(nsISidebar) &&
+        !iid.equals(nsISidebarExternal) &&
         !iid.equals(nsIClassInfo) &&
-        !iid.equals(nsISupports) &&
-        !iid.equals(nsISidebar_MOZILLA_1_8_BRANCH) &&
-        !iid.equals(nsISidebarExternal))
+        !iid.equals(nsISupports))
         throw Components.results.NS_ERROR_NO_INTERFACE;
     return this;
 }
