@@ -1,4 +1,4 @@
-//@line 37 "/usr/obj/ports/mozilla-firefox-2.0.0.16p3/mozilla/toolkit/components/viewsource/content/viewSourceUtils.js"
+//@line 37 "/usr/obj/ports/mozilla-firefox-3.0.6/mozilla/toolkit/components/viewsource/content/viewSourceUtils.js"
 
 /*
  * To keep the global namespace safe, don't define global variables and 
@@ -18,12 +18,22 @@ var gViewSourceUtils = {
   {
     // try to open a view-source window while inheriting the charset (if any)
     var charset = null;
-    if (aDocument)
+    var isForcedCharset = false;
+    if (aDocument) {
       charset = "charset=" + aDocument.characterSet;
+      try { 
+        isForcedCharset =
+          aDocument.defaultView
+                   .QueryInterface(Components.interfaces.nsIInterfaceRequestor)
+                   .getInterface(Components.interfaces.nsIDOMWindowUtils)
+                   .docCharsetIsForced;
+      } catch (ex) {
+      }
+    }
     openDialog("chrome://global/content/viewSource.xul",
                "_blank",
                "all,dialog=no",
-               aURL, charset, aPageDescriptor);
+               aURL, charset, aPageDescriptor, 0, isForcedCharset);
   },
 
   // aCallBack is a function accepting two arguments - result (true=success) and a data object
@@ -84,6 +94,7 @@ var gViewSourceUtils = {
       }
     } catch (ex) {
       // we failed loading it with the external editor.
+      Components.utils.reportError(ex);
       this.handleCallBack(aCallBack, false, data);
       return;
     }
@@ -130,7 +141,7 @@ var gViewSourceUtils = {
       }
     }
     catch (ex) {
-      dump(ex);
+      Components.utils.reportError(ex);
     }
     return editor;
   },
@@ -189,6 +200,7 @@ var gViewSourceUtils = {
           gViewSourceUtils.handleCallBack(this.callBack, true, this.data);
         } catch (ex) {
           // we failed loading it with the external editor.
+          Components.utils.reportError(ex);
           gViewSourceUtils.handleCallBack(this.callBack, false, this.data);
         } finally {
           this.destroy();
